#include <stdio.h>
#include <string.h>
#include <assert.h>
#include <stdlib.h>
#include <ctype.h>

/*
 *  cgen5:     simple macro processor, expand templates against fields.
 *		we read an input file in which:
 *	        - some lines are of the form "TEMPLATE,template"
 *	          which sets T=template.  the template may contain any
 *		  number of <0> and <1> field values.
 *	        - every other line is a 2-tuple of fields
 *  	        and we produce output in which each 2-tuple line A,B
 *       	produces a copy of the template with every occurrence
 *		of <0> replaced by A, and every occurrence of <1> replaced
 *		by B.
 */


// int ok = readline( in, buf, maxlen );
//	read a line (no more than maxlen chars long) from "in",
//	storing it in buf.  remove the trailing newline if there is
//	one.  return 0 for eof, 1 otherwise
//
int readline( FILE *in, char *buf, int maxlen )
{
	if( fgets( buf, maxlen, in ) == 0 )
	{
		return 0;
	}
	int l = strlen(buf);
	if( l>0 && buf[l-1]=='\n' )
	{
		buf[l-1] = '\0';
	}
	return 1;
}


// expand( stdout, template, nfields, fields );
//	expand the given template replacing all occurrences of <i> with
//	field[i], writing the resultant line (and a trailing newline) to out.
//	nfields is the number of fields.
//
void expand( FILE *out, char *template, int nfields, char **fields )
{
	char *p;
	for( p = template; *p!='\0'; p++ )
	{
		if( *p != '<'
		||  ! isdigit(p[1])
		||  p[2] != '>' )
		{
			fputc( *p, out );
			continue;
		}
		if( p[1] >= '0'+nfields )
		{
			fprintf( stderr,
				"error: use of <%c> where nfields=%d\n",
				p[1], nfields );
			exit(1);
		}
		// found valid <i>, copy appropriate field onto output
		fputs( fields[p[1]-'0'], out );
		p+=2;
	}
	fputc( '\n', out );
}


#define STRSIZE 1024

int main( int argc, char **argv )
{
	char template[STRSIZE];
	strcpy( template, "" );

	char *fields[2];

	char line[STRSIZE];
	while( readline(stdin, line, STRSIZE ) != 0 )
	{
		//printf( "// debug: read line '%s'\n", line );
		char *sep = strchr( line, ',' );
		assert( sep != NULL );
		assert( *sep == ',' );
		*sep = '\0';
		char *field0 = line;
		char *field1 = sep+1;
		assert( *field1 != '\0' );
		//printf( "// debug: field0='%s', field1='%s'\n", field0, field1 );
		if( strcmp(field0,"TEMPLATE")==0 )
		{
			strcpy( template, field1 );
			continue;
		}
		if( strlen(template) == 0 )
		{
			fprintf( stderr, "error: TEMPLATE line needed first\n" );
			exit(1);
		}
		//printf( "// debug: field0='%s', field1='%s'\n", field0, field1 );
		fields[0] = field0;
		fields[1] = field1;
		expand( stdout, template, 2, fields );
	}
	exit(0);
	return 0;
}
